==> jcabi-xml-0.16.2-sources.jar: com/jcabi/xml/XSL.java <==
/**
 * Copyright (c) 2012-2014, jcabi.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met: 1) Redistributions of source code must retain the above
 * copyright notice, this list of conditions and the following
 * disclaimer. 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution. 3) Neither the name of the jcabi.com nor
 * the names of its contributors may be used to endorse or promote
 * products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.jcabi.xml;

import com.jcabi.aspects.Immutable;
import javax.validation.constraints.NotNull;

/**
 * XSL stylesheet.
 *
 * <p>Implementation of this interface must be immutable and thread-safe.
 *
 * @author Yegor Bugayenko (yegor@tpc2.com)
 * @version $Id$
 * @since 0.4
 * @see XSLDocument
 */
@Immutable
public interface XSL {

    /**
     * Transform XML to another one.
     * @param xml Source XML document
     * @return Result document
     */
    @NotNull(message = "XML is never NULL")
    XML transform(@NotNull(message = "XML can't be NULL") XML xml);

    /**
     * Transform XML into text.
     * @param xml Source XML document
     * @return Result text
     * @since 0.11
     */
    @NotNull(message = "result text is never NULL")
    String applyTo(@NotNull(message = "XML can't be NULL") XML xml);

    /**
     * With this sources.
     * @param src Sources
     * @return New XSL document
     */
    @NotNull(message = "XSL is never NULL")
    XSL with(@NotNull(message = "sources can't be NULL") Sources src);

    /**
     * With this parameter.
     * @param name Name of XSL parameter
     * @param value Value of XSL parameter
     * @return New XSL document
     * @since 0.16
     */
    @NotNull(message = "XSL is never NULL")
    XSL with(@NotNull(message = "parameter name can't be NULL") String name,
        @NotNull(message = "parameter value can't be NULL") String value);

}

==> jcabi-xml-0.21.1-sources.jar: com/jcabi/xml/XSL.java <==
/**
 * Copyright (c) 2012-2017, jcabi.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met: 1) Redistributions of source code must retain the above
 * copyright notice, this list of conditions and the following
 * disclaimer. 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution. 3) Neither the name of the jcabi.com nor
 * the names of its contributors may be used to endorse or promote
 * products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.jcabi.xml;

/**
 * XSL stylesheet.
 *
 * <p>Implementation of this interface must be immutable and thread-safe.
 *
 * @author Yegor Bugayenko (yegor256@gmail.com)
 * @version $Id: 7b48d210e1aee4e55c1612d4b104115728262cfc $
 * @see XSLDocument
 * @since 0.4
 * @checkstyle AbbreviationAsWordInNameCheck (5 lines)
 */
public interface XSL {

    /**
     * Transform XML to another one.
     * @param xml Source XML document
     * @return Result document
     */
    XML transform(XML xml);

    /**
     * Transform XML into text.
     * @param xml Source XML document
     * @return Result text
     * @since 0.11
     */
    String applyTo(XML xml);

    /**
     * With this sources.
     * @param src Sources
     * @return New XSL document
     */
    XSL with(Sources src);

    /**
     * With this parameter.
     * @param name Name of XSL parameter
     * @param value Value of XSL parameter
     * @return New XSL document
     * @since 0.16
     */
    XSL with(String name, Object value);

}
